@@ -1,4 +1,6 @@
 from tensorhelper.custom_tensor import image_reader
 from tensorhelper.custom_tensor import plot_generator
 from tensorhelper.custom_tensor import load_custom_images
-from tensorhelper.custom_tensor import make_confusion_matrix
\ No newline at end of file
+from tensorhelper.custom_tensor import make_confusion_matrix
+from tensorhelper.custom_tensor import create_tensorboard_callback
+from tensorhelper.custom_tensor import create_tensorhub_model
\ No newline at end of file
